==> ooo_dev_tools-0.17.13-py3-none-any.whl: ooodev/draw/__init__.py <==
from ooo.dyn.awt.point import Point as Point
from ooo.dyn.drawing.line_style import LineStyle as LineStyle
from ooo.dyn.drawing.polygon_flags import PolygonFlags as PolygonFlags
from ooo.dyn.presentation.animation_speed import AnimationSpeed as AnimationSpeed
from ooo.dyn.presentation.fade_effect import FadeEffect as FadeEffect

from ooodev.office.draw import Draw as Draw
from ooodev.units import Angle as Angle
from ooodev.utils.data_type.image_offset import ImageOffset as ImageOffset
from ooodev.utils.data_type.intensity import Intensity as Intensity
from ooodev.utils.data_type.poly_sides import PolySides as PolySides
from ooodev.utils.dispatch.shape_dispatch_kind import ShapeDispatchKind as ShapeDispatchKind
from ooodev.utils.kind.drawing_bitmap_kind import DrawingBitmapKind as DrawingBitmapKind
from ooodev.utils.kind.drawing_gradient_kind import DrawingGradientKind as DrawingGradientKind
from ooodev.utils.kind.drawing_hatching_kind import DrawingHatchingKind as DrawingHatchingKind
from ooodev.utils.kind.drawing_layer_kind import DrawingLayerKind as DrawingLayerKind
from ooodev.utils.kind.drawing_name_space_kind import DrawingNameSpaceKind as DrawingNameSpaceKind
from ooodev.utils.kind.drawing_shape_kind import DrawingShapeKind as DrawingShapeKind
from ooodev.utils.kind.drawing_slide_show_kind import DrawingSlideShowKind as DrawingSlideShowKind
from ooodev.utils.kind.glue_points_kind import GluePointsKind as GluePointsKind
from ooodev.utils.kind.graphic_style_kind import GraphicStyleKind as GraphicStyleKind
from ooodev.utils.kind.presentation_kind import PresentationKind as PresentationKind
from ooodev.utils.kind.shape_comb_kind import ShapeCombKind as ShapeCombKind
from ooodev.utils.kind.zoom_kind import ZoomKind as ZoomKind

from .draw_doc import DrawDoc as DrawDoc
from .draw_page import DrawPage as DrawPage
from .draw_pages import DrawPages as DrawPages
from .draw_text import DrawText as DrawText
from .draw_text_cursor import DrawTextCursor as DrawTextCursor
from .impress_doc import ImpressDoc as ImpressDoc
from .impress_page import ImpressPage as ImpressPage
from .master_draw_page import MasterDrawPage as MasterDrawPage

__all__ = [
    "DrawDoc",
    "DrawPage",
    "DrawPages",
    "DrawText",
    "DrawTextCursor",
    "ImpressDoc",
    "ImpressPage",
    "MasterDrawPage",
]

==> ooo_dev_tools-0.32.1-py3-none-any.whl: ooodev/draw/__init__.py <==
from ooo.dyn.awt.point import Point as Point
from ooo.dyn.drawing.line_style import LineStyle as LineStyle
from ooo.dyn.drawing.polygon_flags import PolygonFlags as PolygonFlags
from ooo.dyn.presentation.animation_speed import AnimationSpeed as AnimationSpeed
from ooo.dyn.presentation.fade_effect import FadeEffect as FadeEffect

from ooodev.events.draw_named_event import DrawNamedEvent as DrawNamedEvent
from ooodev.office.draw import Draw as Draw
from ooodev.units.angle import Angle as Angle
from ooodev.utils.data_type.image_offset import ImageOffset as ImageOffset
from ooodev.utils.data_type.intensity import Intensity as Intensity
from ooodev.utils.data_type.poly_sides import PolySides as PolySides
from ooodev.utils.dispatch.shape_dispatch_kind import ShapeDispatchKind as ShapeDispatchKind
from ooodev.utils.kind.drawing_bitmap_kind import DrawingBitmapKind as DrawingBitmapKind
from ooodev.utils.kind.drawing_gradient_kind import DrawingGradientKind as DrawingGradientKind
from ooodev.utils.kind.drawing_hatching_kind import DrawingHatchingKind as DrawingHatchingKind
from ooodev.utils.kind.drawing_layer_kind import DrawingLayerKind as DrawingLayerKind
from ooodev.utils.kind.drawing_name_space_kind import DrawingNameSpaceKind as DrawingNameSpaceKind
from ooodev.utils.kind.drawing_shape_kind import DrawingShapeKind as DrawingShapeKind
from ooodev.utils.kind.drawing_slide_show_kind import DrawingSlideShowKind as DrawingSlideShowKind
from ooodev.utils.kind.glue_points_kind import GluePointsKind as GluePointsKind
from ooodev.utils.kind.graphic_style_kind import GraphicStyleKind as GraphicStyleKind
from ooodev.utils.kind.presentation_kind import PresentationKind as PresentationKind
from ooodev.utils.kind.shape_comb_kind import ShapeCombKind as ShapeCombKind
from ooodev.utils.kind.zoom_kind import ZoomKind as ZoomKind

from .draw_doc import DrawDoc as DrawDoc
from .draw_form import DrawForm as DrawForm
from .draw_forms import DrawForms as DrawForms
from .draw_page import DrawPage as DrawPage
from .draw_pages import DrawPages as DrawPages
from .draw_text import DrawText as DrawText
from .draw_text_cursor import DrawTextCursor as DrawTextCursor
from .generic_draw_page import GenericDrawPage as GenericDrawPage
from .generic_draw_pages import GenericDrawPages as GenericDrawPages
from .impress_doc import ImpressDoc as ImpressDoc
from .impress_page import ImpressPage as ImpressPage
from .impress_pages import ImpressPages as ImpressPages
from .master_draw_page import MasterDrawPage as MasterDrawPage
from .shape_collection import ShapeCollection as ShapeCollection

__all__ = [
    "DrawDoc",
    "DrawForm",
    "DrawForms",
    "DrawPage",
    "DrawPages",
    "DrawText",
    "DrawTextCursor",
    "GenericDrawPage",
    "GenericDrawPages",
    "ImpressDoc",
    "ImpressPage",
    "ImpressPages",
    "MasterDrawPage",
    "ShapeCollection",
]
